import * as React from 'react';
import { Table, Header, Container, Form, Checkbox, Button } from 'semantic-ui-react';
import { ProbeDetails } from './ProbeDetails';
import { ListContainer } from './commons/ListContainer';

export interface Props {

}

export interface State {
  selected: object;
  isDetail: boolean;
  list: object[];
}

export class Probes extends React.Component<Props, State> {

  private data: any;

  constructor(props: any, context: any) {
    super(props, context);

    this.state = {
      selected: null,
      isDetail: false,
      list: null,
    };
  }

  public componentWillMount(): void {
    super.componentWillMount();
    this.data = [
      {
        'id': '11',
        'metaProbeStatus': {
          'name': 'STARTED',
        },
        'domain': {
          'name': 'asus',
        },
        'probeKey': '1AGBLKDFJ2452ASDGFL2KWJLKSDJ',
        'description': 'description1111111111',
      },
      {
        'id': '22',
        'metaProbeStatus': {
          'name': 'STOPPED',
        },
        'domain': {
          'name': 'ottugi',
        },
        'probeKey': '2AGBLKDFJ2452ASDGFL2KWJLKSDJ',
        'description': 'description22222222',
      },
      {
        'id': '33',
        'metaProbeStatus': {
          'name': 'STOPPED',
        },
        'domain': {
          'name': 'lg',
        },
        'probeKey': '3AGBLKDFJ2452ASDGFL2KWJLKSDJ',
        'description': 'description33333',
      },
      {
        'id': '44',
        'metaProbeStatus': {
          'name': 'STARTED',
        },
        'domain': {
          'name': 'apple',
        },
        'probeKey': '4AGBLKDFJ2452ASDGFL2KWJLKSDJ',
        'description': 'description4444',
      },
    ];
    this.setState({
      list: this.data,
    });
  }

  public checkCellStatus(status: any): boolean {
    if (status.name === 'STOPPED') {
      return true;
    }
    return false;
  }

  public handleSelect(selectedProbe: object): void {
    this.setState({
      selected: selectedProbe,
      isDetail: true,
    });
  }

  public handleSearch(result: object[]): void {
    this.setState({
      list: result,
    });
  }

  public handleFilter(filterStr: string): void {
    if (filterStr === null) {
      this.setState({
        list: this.data,
      });
      return;
    }
    let founds = new Array();
    for (let probe of this.data) {
      if (probe.metaProbeStatus.name.indexOf(filterStr) !== -1) {
        founds.push(probe);
      }
    }
    this.setState({
      list: founds,
    });
  }

  public render(): JSX.Element {
    if (this.state.isDetail) {
      return <ProbeDetails probe={this.state.selected} onBack={() => this.setState({ isDetail: false })} />;
    }
    let probeList =
      <Container fluid>
        <Table selectable striped>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell textAlign={'center'}>Name</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>CIDR</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Status</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Target Count</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Sensor Count</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.renderRows()}
          </Table.Body>
        </Table>
      </Container>;

    return (
      <ListContainer
        contents={probeList}
        data={this.data}
        onSearch={this.handleSearch.bind(this)}
        filter={<ProbeFilter onFilter={this.handleFilter.bind(this)} />}
      />
    );
  }

  private renderRows(): (JSX.Element | JSX.Element[]) {
    if (this.state.list.length === 0) {
      return <Table.Row error >
        <Table.Cell textAlign='center' colSpan='5'>No results found.</Table.Cell>
      </Table.Row>;
    }
    return this.state.list.map((probe: any, index: number) => (
      <Table.Row key={index} onClick={this.handleSelect.bind(this, probe)}>
        <Table.Cell >{probe.domain.name}</Table.Cell>
        <Table.Cell>{index}</Table.Cell>
        <Table.Cell negative={this.checkCellStatus(probe.metaProbeStatus)} textAlign={'center'}>{probe.metaProbeStatus.name}</Table.Cell>
        <Table.Cell textAlign={'center'} >todo. {probe.targetCnt}</Table.Cell>
        <Table.Cell textAlign={'center'} >todo. {probe.sensorCnt}</Table.Cell>
      </Table.Row>
    ));
  }

}

export class ProbeFilter extends React.Component<any, any> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      status: null,
    };
  }

  public handleChange(e: any, data: any): void {
    this.setState({
      status: data.value,
    });
    this.props.onFilter(data.value);
  }
  public handleReset(e: any, data: any): void {
    this.setState({
      status: null,
    });
    this.props.onFilter(null);
  }

  public render(): JSX.Element {
    // todo. getting MetaProbeStatus
    let metaProbeStatus = [
      {
        'id': '1',
        'name': 'STARTED',
      },
      {
        'id': '2',
        'name': 'STOPPED',
      },
    ];
    return (
      <Form>
        <Container fluid>
          <Button size='mini' floated='right' basic content='Reset' onClick={this.handleReset.bind(this)} />
          <Form.Field>
            <b>Status</b>
          </Form.Field>

          {metaProbeStatus.map((item: any, index: number) => (
            <Form.Field key={index}>
              <Checkbox
                radio
                label={item.name}
                name='status'
                value={item.name}
                checked={this.state.status === item.name}
                onChange={this.handleChange.bind(this)}
              />
            </Form.Field>
          ))}
        </Container>
      </Form>
    );
  }
}



